@@ -18,15 +18,28 @@
 
 """Some tools for working with Gentoo.
 
+Usage: babtools_gentoo.py cmd [OPTIONS]
+        or: babtools_gentoo.py --help
+
 Avaible commands: 
  - ebuild_to_local CP
- 
-   CP (cathegory/package) in the simple form dev-lang/python or similar. CPVs (cathegory/package-version) aren't supported, yet. 
    
+   CP (cathegory/package) in the simple form dev-lang/python or similar. CPVs (cathegory/package-version) aren't supported, yet. 
+    
  - ebuild_download_to_local CP URL
- 
+  
    Download an ebuild from bugs.gentoo.org to the local portage tree.    
 
+Examples: 
+ - sudo babtools_gentoo.py ebuild_to_local dev-lang/python
+   
+   copy dev-lang/python into the local overlay
+   
+ - sudo python babtools_gentoo.py ebuild_download_to_local games-rpg/vegastrike http://bugs.gentoo.org/attachment.cgi?id=151789
+   
+   Download the ebuild for games-rpg/vegastrike from bugs.gentoo.org and digest it. 
+
+
 Source URL (Mercurial): U{http://freehg.org/u/ArneBab/babtools_gentoo/}
 
 PyPI URL: U{http://pypi.python.org/pypi/babtools_gentoo}
@@ -157,20 +170,26 @@ def create_local_ebuild_dir(CP):
 
 def print_help(): 
     """Display help and a list of commands."""
-    print "Usage: babtools_gentoo.py cmd [OPTIONS]"
-    print "  or: babtools_gentoo.py --help"
+    # Just print the second paragraph of the docstring (paragraphs seperated by really empty lines). 
+    print __doc__.split("\n\n")[1]
+    # Print two empty lines. 
+    print ""
     print ""
     list_commands()
+    # Print two empty lines. 
+    print ""
+    print ""
+    print_examples()
 
 def list_commands():
     """List avaible commands."""
+    # Just print the third paragraph of the docstring. 
+    print __doc__.split("\n\n")[2]
     
-    print "Avaible commands: "
-    print " - ebuild_to_local CP"
-    print "   CP (cathegory/package) in the simple form dev-lang/python or similar. CPVs (cathegory/package-version) aren't supported, yet. "
-    print ""
-    print " - ebuild_download_to_local CP URL"
-    print "   Download an ebuild from bugs.gentoo.org to the local portage tree. "
+def print_examples():
+    """List avaible commands."""
+    # Just print the fourth paragraph of the docstring. 
+    print __doc__.split("\n\n")[3]
 
 #### Self-Test ####
 
